@@ -2,9 +2,10 @@ use 5.006; use strict; use warnings;
 
 package Parse::MIME;
 
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 
-use Exporter 'import';
+use Exporter ();
+our @ISA = 'Exporter';
 our @EXPORT_OK = qw(
 	&parse_mime_type &parse_media_range &parse_media_range_list 
 	&fitness_and_quality_parsed &quality_parsed &quality
